# PulpAnsibleClient::ContentCollectionSignaturesApi

All URIs are relative to *https://pulp*

Method | HTTP request | Description
------------- | ------------- | -------------
[**list**](ContentCollectionSignaturesApi.md#list) | **GET** /pulp/api/v3/content/ansible/collection_signatures/ | List collection version signatures
[**read**](ContentCollectionSignaturesApi.md#read) | **GET** {ansible_collection_version_signature_href} | Inspect a collection version signature



## list

> PaginatedansibleCollectionVersionSignatureResponseList list(opts)

List collection version signatures

ViewSet for looking at signature objects for CollectionVersion content.

### Example

```ruby
# load the gem
require 'pulp_ansible_client'
# setup authorization
PulpAnsibleClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpAnsibleClient::ContentCollectionSignaturesApi.new
opts = {
  limit: 56, # Integer | Number of results to return per page.
  offset: 56, # Integer | The initial index from which to return the results.
  ordering: 'ordering_example', # String | Which field to use when ordering the results.
  pubkey_fingerprint: 'pubkey_fingerprint_example', # String | Filter results where pubkey_fingerprint matches value
  pubkey_fingerprint__in: ['pubkey_fingerprint__in_example'], # Array<String> | Filter results where pubkey_fingerprint is in a comma-separated list of values
  repository_version: 'repository_version_example', # String | Repository Version referenced by HREF
  repository_version_added: 'repository_version_added_example', # String | Repository Version referenced by HREF
  repository_version_removed: 'repository_version_removed_example', # String | Repository Version referenced by HREF
  signed_collection: 'signed_collection_example', # String | Filter results where signed_collection matches value
  signing_service: 'signing_service_example', # String | Filter results where signing_service matches value
  fields: 'fields_example', # String | A list of fields to include in the response.
  exclude_fields: 'exclude_fields_example' # String | A list of fields to exclude from the response.
}

begin
  #List collection version signatures
  result = api_instance.list(opts)
  p result
rescue PulpAnsibleClient::ApiError => e
  puts "Exception when calling ContentCollectionSignaturesApi->list: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **limit** | **Integer**| Number of results to return per page. | [optional] 
 **offset** | **Integer**| The initial index from which to return the results. | [optional] 
 **ordering** | **String**| Which field to use when ordering the results. | [optional] 
 **pubkey_fingerprint** | **String**| Filter results where pubkey_fingerprint matches value | [optional] 
 **pubkey_fingerprint__in** | [**Array&lt;String&gt;**](String.md)| Filter results where pubkey_fingerprint is in a comma-separated list of values | [optional] 
 **repository_version** | **String**| Repository Version referenced by HREF | [optional] 
 **repository_version_added** | **String**| Repository Version referenced by HREF | [optional] 
 **repository_version_removed** | **String**| Repository Version referenced by HREF | [optional] 
 **signed_collection** | [**String**](.md)| Filter results where signed_collection matches value | [optional] 
 **signing_service** | [**String**](.md)| Filter results where signing_service matches value | [optional] 
 **fields** | **String**| A list of fields to include in the response. | [optional] 
 **exclude_fields** | **String**| A list of fields to exclude from the response. | [optional] 

### Return type

[**PaginatedansibleCollectionVersionSignatureResponseList**](PaginatedansibleCollectionVersionSignatureResponseList.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## read

> AnsibleCollectionVersionSignatureResponse read(ansible_collection_version_signature_href, opts)

Inspect a collection version signature

ViewSet for looking at signature objects for CollectionVersion content.

### Example

```ruby
# load the gem
require 'pulp_ansible_client'
# setup authorization
PulpAnsibleClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpAnsibleClient::ContentCollectionSignaturesApi.new
ansible_collection_version_signature_href = 'ansible_collection_version_signature_href_example' # String | 
opts = {
  fields: 'fields_example', # String | A list of fields to include in the response.
  exclude_fields: 'exclude_fields_example' # String | A list of fields to exclude from the response.
}

begin
  #Inspect a collection version signature
  result = api_instance.read(ansible_collection_version_signature_href, opts)
  p result
rescue PulpAnsibleClient::ApiError => e
  puts "Exception when calling ContentCollectionSignaturesApi->read: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ansible_collection_version_signature_href** | **String**|  | 
 **fields** | **String**| A list of fields to include in the response. | [optional] 
 **exclude_fields** | **String**| A list of fields to exclude from the response. | [optional] 

### Return type

[**AnsibleCollectionVersionSignatureResponse**](AnsibleCollectionVersionSignatureResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json

